@@ -79,7 +79,7 @@ estimate.list <- function(x,...) {
 ##' estimate(g,"*Int*","z")
 ##' estimate(g,"1","2"-"3",null=c(0,1))
 ##' estimate(g,2,3)
-##' 
+##'
 ##' ## Usual (non-robust) confidence intervals
 ##' estimate(g,robust=FALSE)
 ##'
@@ -218,7 +218,7 @@ estimate.default <- function(x=NULL,f=NULL,...,data,id,
     alpha <- 1-level
     alpha.str <- paste(c(alpha/2,1-alpha/2)*100,"",sep="%")
     nn <- NULL
-    if (missing(vcov) || is.null(vcov) || (is.logical(vcov) && vcov[1]==FALSE)) { ## If user supplied vcov, then don't estimate IC
+    if (missing(vcov) || is.null(vcov) || (is.logical(vcov) && vcov[1]==FALSE && !is.na(vcov[1]))) { ## If user supplied vcov, then don't estimate IC
         if (missing(score.deriv)) {
             if (!is.logical(iid)) {
                 iidtheta <- iid
@@ -230,7 +230,7 @@ estimate.default <- function(x=NULL,f=NULL,...,data,id,
             suppressWarnings(iidtheta <- iid(x,score.deriv=score.deriv,folds=folds))
         }
     } else {
-        if (is.logical(vcov)) vcov <- vcov(x)
+        if (is.logical(vcov) && !is.na(vcov)[1]) vcov <- stats::vcov(x)
         iidtheta <- NULL
     }
 
@@ -335,6 +335,7 @@ estimate.default <- function(x=NULL,f=NULL,...,data,id,
         }
     } else {
         if (!missing(vcov)) {
+            if (length(vcov)==1 && is.na(vcov)) vcov <- matrix(NA,length(pp),length(pp))
             V <- vcov
         } else {
             V <- stats::vcov(x)
@@ -477,19 +478,24 @@ estimate.default <- function(x=NULL,f=NULL,...,data,id,
         }
     }
 
-    if (length(pp)==1) res <- rbind(c(pp,diag(V)^0.5)) else res <- cbind(pp,diag(V)^0.5)
-    beta0 <- res[,1]
-
-    if (!missing(null) && missing(contrast)) beta0 <- beta0-null
-    if (!is.null(df)) {
-        za <- qt(1-alpha/2,df=df)
-        pval <- 2*pt(abs(res[,1]/res[,2]),df=df,lower.tail=FALSE)
+    if (is.null(V)) {
+        res <- cbind(pp,NA,NA,NA,NA)
     } else {
-        za <- qnorm(1-alpha/2)
-        pval <- 2*pnorm(abs(res[,1]/res[,2]),lower.tail=FALSE)
+        if (length(pp)==1) res <- rbind(c(pp,diag(V)^0.5)) else res <- cbind(pp,diag(V)^0.5)
+        beta0 <- res[,1]
+
+        if (!missing(null) && missing(contrast)) beta0 <- beta0-null
+        if (!is.null(df)) {
+            za <- qt(1-alpha/2,df=df)
+            pval <- 2*pt(abs(res[,1]/res[,2]),df=df,lower.tail=FALSE)
+        } else {
+            za <- qnorm(1-alpha/2)
+            pval <- 2*pnorm(abs(res[,1]/res[,2]),lower.tail=FALSE)
+        }
+        res <- cbind(res,res[,1]-za*res[,2],res[,1]+za*res[,2],pval)
     }
-    res <- cbind(res,res[,1]-za*res[,2],res[,1]+za*res[,2],pval)
     colnames(res) <- c("Estimate","Std.Err",alpha.str,"P-value")
+
     if (!is.null(nn)) {
         rownames(res) <- nn
     } else {
@@ -659,7 +665,7 @@ estimate.glm <- function(x,...) {
 }
 
 ##' @export
-print.estimate <- function(x,level=0,digits=3,width=25,std.error=TRUE,p.value=TRUE,...) {
+print.estimate <- function(x,level=0,digits=4,width=25,std.error=TRUE,p.value=TRUE,...) {
     if (!is.null(x$print)) {
         x$print(x,digits=digits,width=width,...)
         return(invisible(x))
